@@ -1070,6 +1070,9 @@ def get_files(search_path=False, **kwargs):
                 if equal to "images" it will automatically search for these extensions:
                     bmp,dds,dib,eps,gif,icns,ico,im,jpg,jpeg,jpeg 2000,msp,pcx,png,ppm,sgi,spider,tga,tiff,webp,xbm
 
+            [`show count`=True] {bool}
+                If True, the index count is printed to the terminal during indexing.
+
             [`threaded`=True] {bool}
                 if True, the process is multi-threaded,
                 this makes indexing much faster,
@@ -1080,8 +1083,10 @@ def get_files(search_path=False, **kwargs):
                 By default it will get this:
                     ['file_name', 'extension', 'name_no_ext', 'dir_path', 'access_time',
                     'modified_time', 'created_time', 'size']
+
                 so the list you provide will limit the amount of
                 reading/formatting needed to gather data.
+
                 Example:
                     ['modified_time','size']  will take ~0.000129939 seconds per file on an SSD
 
@@ -1093,7 +1098,7 @@ def get_files(search_path=False, **kwargs):
 
             [`ftp`=None] {obj}
                 A reference to the ftputil object.
-                
+
             [`include_meta_data`=False] {bool}
                 If True any images that are found will have their meta_data added to the file object.
                 
@@ -1193,7 +1198,7 @@ def get_files(search_path=False, **kwargs):
                     # print(f"file found.")
                     file_array.append(file_data)
                     if show_index_count is True:
-                        print(f"files indexed: {len(file_array)}",end="\r",flush=True)
+                        print(f"files indexed: {len(file_array)}                                             ",end="\r",flush=True)
                 # else:
                     # print(f"file_data is none")
             if recursive is False:
@@ -1205,10 +1210,32 @@ def get_files(search_path=False, **kwargs):
     if include_meta_data is True:
         file_array = _add_jpg_meta_data(file_array)
     if show_index_count is True:
-        print(f"Total Files Indexed: {len(file_array)}")
+        print(f"Total Files Indexed: {len(file_array)}                                             ")
     return file_array
 
 def _add_jpg_meta_data(file_array):
+    '''
+        Gathers meta data for jpg files.
+
+        ----------
+
+        Arguments
+        -------------------------
+        `file_array` {list}
+            A list of file objects
+
+        Return {list}
+        ----------------------
+        A list of jpg file objects with meta data applied.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 02-05-2022 09:58:56
+        `memberOf`: file
+        `version`: 1.0
+        `method_name`: _add_jpg_meta_data
+    '''
     # print(f"_add_jpg_meta_data.file_array: {len(file_array)}")
     result_array = []
     jpg_array = []
@@ -1462,7 +1489,7 @@ class GetFilesThreaded:
 
         self.file_array.append(file_data)
         if self.show_index_count is True:
-            print(f"files indexed: {len(self.file_array)}",end="\r",flush=True)
+            print(f"files indexed: {len(self.file_array)}                                             ",end="\r",flush=True)
 
     def single_file_thread(self, data):
         '''
@@ -1539,7 +1566,7 @@ class GetFilesThreaded:
         if self.include_meta_data is True:
             self.file_array = _add_jpg_meta_data(self.file_array)
         if self.show_index_count is True:
-            print(f"Total Files Indexed: {len(self.file_array)}")
+            print(f"Total Files Indexed: {len(self.file_array)}                                             ")
         return self.file_array
 
         # def _get_files_single_thread(search_path=False, recursive=False, exclude=None, include=None, extensions=None, data_include=None):
